@@ -11,21 +11,13 @@ BASEURL = "https://frc-api.firstinspires.org/v3.0/"
 
 
 class Config:
-    """This class is used for configuring the FrcApi wrapper."""
+    """This class is used to store info."""
 
     def key(self, api_key: str) -> None:
         """Set the api key."""
         self.api_key = api_key
 
     def encode_key(self, api_key: str, username: str) -> None:
-        """
-        Proprly encodes the api key and username.
-
-        self: An instance of the Config class.
-
-        api_key: The api key.
-
-        username: The username.
-        """
+        """Encode the api key."""
         encode = base64.b64encode(f"{username}:{api_key}".encode("utf-8"))
         self.api_key = encode.decode("utf-8")
